import Taro, { Component } from '@tarojs/taro'
import { View, ScrollView, Block } from '@tarojs/components'
import HouseCard from '../../components/HouseCard'
import RaiseCard from '../../components/RaiseCard'
import { queryPreselectionRecord } from '@/services/project'
import { connect } from '@tarojs/redux'
import ready from '@/utils/ready'
import Blank from '../../components/Blank'
import Statement from '../../components/Statement'
import { transferImage } from '@/utils/tools'
import PickerComponent from '../../components/Picker'
import './index.scss'

@connect(
  ({ user }) => ({ ...user })
)

export default class Records extends Component {
  config = {
    navigationBarTitleText: '选房记录'
  }

  state = {
    recordList: [],
    current: 0,
    noRecord: false,
    building: '',
    saleBatch: '',
    status: '',
  }
  componentDidShow() {
    ready.queue(() => {

      const { userInfo: { person: { personId } } } = this.props
      const params = {
        personId,
        pageNum: 1,
        pageSize: 999,
      }
      queryPreselectionRecord(params).then(res => {
        const list = res.records
        this.setState({
          recordList: list.filter(item => item.status == '1') || [],

        }, () => {
          this.setState({
            noRecord: this.state.recordList.length > 0 ? false : true
          })
        })
      })
    })
  }
  // toHouseDetail(item) {
  //   if (item.housingStatus == '0' || item.saleBatchStatus == '0') {
  //     Taro.showToast({ title: '当前销售批次或该房源已被取消发布', icon: 'none', duration: 2000 })
  //   } else {
  //     Taro.navigateTo({
  //       url: `/onlineSelling/pages/detail/index?id=${item.houseId}`
  //     })
  //   }
  // }
  CheckboxChange = (e) => {
    e.stopPropagation()
    console.log('checkbox发生change事件，携带value值为：', e)
  }

  renderPreselection() {
    const { recordList, noRecord } = this.state
    return (
      <Block>
        <ScrollView scrollY className="container">
          <CheckboxGroup onChange={this.CheckboxChange}>
            {
              noRecord ? <Blank style="margin:14vh 0 32vh 0" tips="暂无预选记录" /> :
                <View>
                {
                  recordList.map((item) => {
                    return (
                      <Label class="checkbox" >
                        <Checkbox value={item.houseId} checked={item.checked} >
                          <View className="carditem" key={item.preselectionRecordId} >

                            <HouseCard summary={item} />
                          </View>
                        </Checkbox>
                      </Label>
                    )
                  })
                }
                </View>
            }
          </CheckboxGroup>
          <Statement />
        </ScrollView >

        <View className="raise-box"> <View className="raise-btn">认筹房源</View></View>

      </Block>
    )
  }
  renderRaise() {
    const { recordList, noRecord } = this.state
    return (
      <Block>

        {
          noRecord ? <Blank style="margin:14vh 0 32vh 0" tips="暂无认筹记录" /> :
            <ScrollView scrollY>
              {
                recordList.map(item => (
                  <View key={item.preselectionRecordId} >
                    <RaiseCard summary={item} />
                  </View>
                )
                )
              }
            </ScrollView >
        }
        <Statement />


      </Block>
    )
  }
  onSexChange = e => {
    let building = e.detail.value == '0' ? '1' : e.detail.value == '1' ? '2' : ''
    this.setState({
      building,
    })
  }
  handleSaleBatchChange = e => {
    const selector = [{ buildingTypeName: '楼盘1' }, { buildingTypeName: '楼盘2' }, { buildingTypeName: '楼盘3' }, { buildingTypeName: '楼盘4' }]
    this.setState({
      saleBatch: selector[e.detail.value].buildingTypeName
    })
  }
  handleStatusChange = e => {

    let status = e.detail.value == '0' ? '1' : e.detail.value == '1' ? '2' : ''
    this.setState({
      status,
    })
  }
  renderRaiseScreen() {
    const { building, saleBatch, status } = this.state
    const sexSelector = ['男', '女']
    const selector = [{ buildingTypeName: '楼盘1' }, { buildingTypeName: '楼盘2' }, { buildingTypeName: '楼盘3' }, { buildingTypeName: '楼盘4' }]
    return (

      <View className="base-con">
        <PickerComponent title="选择楼盘" selector={sexSelector} currentValue={building == '1' ? '男' : building == '2' ? '女' : '　'} handleChange={this.onSexChange} />
        <PickerComponent title="选择销售批次" selector={selector} key={"buildingTypeName"} currentValue={saleBatch || '　'} handleChange={this.handleSaleBatchChange} />
        <PickerComponent title="锁定状态" selector={selector} key={"buildingTypeName"} currentValue={status || '　'} handleChange={this.handleStatusChange} />
        <View className="bottom-btn">
          <View className="save" onClick={this.baseSaveBtn}>
            筛选
            </View>
          <View className="cancel" onClick={this.baseCancelBtn}>
            不限
          </View>
        </View>
      </View>
    )
  }

  handleSaleBatchChange = e => {
    const selector = [{ buildingTypeName: '楼盘1' }, { buildingTypeName: '楼盘2' }, { buildingTypeName: '楼盘3' }, { buildingTypeName: '楼盘4' }]
    this.setState({
      saleBatch: selector[e.detail.value].buildingTypeName
    })
  }
  handleApartmentChange = e => {
    const selector = [{ buildingTypeName: '楼盘1' }, { buildingTypeName: '楼盘2' }, { buildingTypeName: '楼盘3' }, { buildingTypeName: '楼盘4' }]
    this.setState({
      status: selector[e.detail.value].buildingTypeName
    })
  }

  renderPreselectScreen() {
    const { building, saleBatch, status } = this.state

    const selector = [{ buildingTypeName: '楼盘1' }, { buildingTypeName: '楼盘2' }, { buildingTypeName: '楼盘3' }, { buildingTypeName: '楼盘4' }]
    return (

      <View className="base-con">
        <PickerComponent title="选择楼盘" selector={selector} currentValue={status || ''} handleChange={this.handleApartmentChange} />
        <PickerComponent title="选择销售批次" selector={selector} currentValue={status || ''} handleChange={this.handleApartmentChange} />
        <PickerComponent title="选择户型" selector={selector} currentValue={status || ''} handleChange={this.handleApartmentChange} />

        <View className="bottom-btn">
          <View className="save" onClick={this.baseSaveBtn}>
            筛选
            </View>
          <View className="cancel" onClick={this.baseCancelBtn}>
            不限
          </View>
        </View>
      </View>
    )
  }


  handleScreenClick() {

  }
  handleCondition(value) {
    this.setState({
      current: value
    })
  }
  renderBar() {
    const { current } = this.state
    const condition = [{ title: '预选记录', value: 0 }, { title: '认筹单', value: 1 }]

    return (
      <Block>
        <View className="screen-top">
          <View className="flex">
            {condition.map(item => (
              <View key={item.value} onClick={() => this.handleCondition(item.value)} className={current == item.value ? 'top-item active' : 'top-item'}>
                {item.title}
              </View>
            ))}
          </View>
          <View onClick={this.handleScreenClick}>
            <Image style="width:50rpx;height:50rpx" src={transferImage(require('../../assets/screen.png'))}></Image>
          </View>
        </View>
        {current == 0 && this.renderPreselection()}
        {current == 1 && this.renderRaise()}
      </Block>
    )
  }
  render() {


    return (
      <View className="records" >
        {/* {this.renderBar()} */}
        {/* {this.renderRaiseScreen()} */}
        {this.renderPreselectScreen()}


      </View >
    )
  }
}
